﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Charts;
using Infragistics.Olap;
using Infragistics.Olap.Data;

namespace OlapAxisWithToolTip
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            DataChart.Series.CollectionChanged += new System.Collections.Specialized.NotifyCollectionChangedEventHandler(Series_CollectionChanged);
        }

        void Series_CollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            if (e.NewItems != null)
            {
                foreach (Series series in e.NewItems)
                {
                    TextBlock tooltipText = new TextBlock();
                    Binding binding = new Binding("Item");
                    binding.Converter = new TooltipConverter();
                    tooltipText.SetBinding(TextBlock.TextProperty, binding);

                    series.ToolTip = tooltipText;
                }
            }
            
        }
    }

    public class TooltipConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            OlapAxisCell cell = value as OlapAxisCell;
            if (cell != null)
            {
                var colTuple = cell.ColumnTuple;
                var rowTuple = cell.RowTuple;

                return string.Format("row: {0}, col: {1}", 
                    GetRootMember(rowTuple.Members.First()), 
                    GetRootMember(colTuple.Members.First()));
            }
            return "";
        }

        private IMember GetRootMember(IMember member)
        {
            if (member.ParentMember == null)
                return member;
            else
                return GetRootMember(member.ParentMember);
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

}
